==> lb-2.27.1.zip: lb/date.lang.php <==
<?php
/**
 * @package Dotclear
 *
 * @copyright Olivier Meunier & Association Dotclear
 * @copyright GPL-2.0-only
 */
#
# DOT NOT MODIFY THIS FILE !
#

use Dotclear\Helper\L10n;

L10n::$locales['%Y-%m-%d %H:%M'] = '';
L10n::$locales['_Jan'] = 'Jan';
L10n::$locales['_Feb'] = 'Feb';
L10n::$locales['_Mar'] = 'Mäe';
L10n::$locales['_Apr'] = 'Abr';
L10n::$locales['_May'] = 'Mee';
L10n::$locales['_Jun'] = 'Jun';
L10n::$locales['_Jul'] = 'Jul';
L10n::$locales['_Aug'] = 'Aug';
L10n::$locales['_Sep'] = 'Sep';
L10n::$locales['_Oct'] = 'Okt';
L10n::$locales['_Nov'] = 'Nov';
L10n::$locales['_Dec'] = 'Dez';
L10n::$locales['January'] = 'Januar';
L10n::$locales['February'] = 'Februar';
L10n::$locales['March'] = 'Mäerz';
L10n::$locales['April'] = 'Abrëll';
L10n::$locales['May'] = 'Mee';
L10n::$locales['June'] = 'Juni';
L10n::$locales['July'] = 'Juli';
L10n::$locales['August'] = 'August';
L10n::$locales['September'] = 'September';
L10n::$locales['October'] = 'Oktober';
L10n::$locales['November'] = 'November';
L10n::$locales['December'] = 'Dezember';
L10n::$locales['_Mon'] = 'Méi';
L10n::$locales['_Tue'] = 'Dën';
L10n::$locales['_Wed'] = 'Mët';
L10n::$locales['_Thu'] = 'Don';
L10n::$locales['_Fri'] = 'Fre';
L10n::$locales['_Sat'] = 'Sam';
L10n::$locales['_Sun'] = 'Son';
L10n::$locales['Monday'] = 'Méindeg';
L10n::$locales['Tuesday'] = 'Dënschdeg';
L10n::$locales['Wednesday'] = 'Mëttwoch';
L10n::$locales['Thursday'] = 'Donneschdeg';
L10n::$locales['Friday'] = 'Freideg';
L10n::$locales['Saturday'] = 'Samschdeg';
L10n::$locales['Sunday'] = 'Sonndeg';

==> lb-2.29.zip: lb/date.lang.php <==
<?php
/**
 * @package Dotclear
 *
 * @copyright Olivier Meunier & Association Dotclear
 * @copyright GPL-2.0-only
 */
#
# DOT NOT MODIFY THIS FILE !
#

use Dotclear\Helper\L10n;

L10n::$locales['%Y-%m-%d %H:%M'] = '';
L10n::$locales['_Jan'] = 'Jan';
L10n::$locales['_Feb'] = 'Feb';
L10n::$locales['_Mar'] = 'Mäe';
L10n::$locales['_Apr'] = 'Abr';
L10n::$locales['_May'] = 'Mee';
L10n::$locales['_Jun'] = 'Jun';
L10n::$locales['_Jul'] = 'Jul';
L10n::$locales['_Aug'] = 'Aug';
L10n::$locales['_Sep'] = 'Sep';
L10n::$locales['_Oct'] = 'Okt';
L10n::$locales['_Nov'] = 'Nov';
L10n::$locales['_Dec'] = 'Dez';
L10n::$locales['January'] = 'Januar';
L10n::$locales['February'] = 'Februar';
L10n::$locales['March'] = 'Mäerz';
L10n::$locales['April'] = 'Abrëll';
L10n::$locales['May'] = 'Mee';
L10n::$locales['June'] = 'Juni';
L10n::$locales['July'] = 'Juli';
L10n::$locales['August'] = '';
L10n::$locales['September'] = '';
L10n::$locales['October'] = 'Oktober';
L10n::$locales['November'] = '';
L10n::$locales['December'] = 'Dezember';
L10n::$locales['_Mon'] = 'Méi';
L10n::$locales['_Tue'] = 'Dën';
L10n::$locales['_Wed'] = 'Mët';
L10n::$locales['_Thu'] = 'Don';
L10n::$locales['_Fri'] = 'Fre';
L10n::$locales['_Sat'] = 'Sam';
L10n::$locales['_Sun'] = 'Son';
L10n::$locales['Monday'] = 'Méindeg';
L10n::$locales['Tuesday'] = 'Dënschdeg';
L10n::$locales['Wednesday'] = 'Mëttwoch';
L10n::$locales['Thursday'] = 'Donneschdeg';
L10n::$locales['Friday'] = 'Freideg';
L10n::$locales['Saturday'] = 'Samschdeg';
L10n::$locales['Sunday'] = 'Sonndeg';
